/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.input;

import java.net.URL;

import ucot.ModulePropertyInterface;

/**
 * <p>
 * Interface for inputs used by UCOT core. Inputs are the
 * modules that handle reading data from given url and
 * parsing usecases from it. User should first check that
 * some URL is readable by this reader by invoking
 * <code>canRead(URL)</code> method. It is up to the Input
 * to set each loaded usecase's url correctly.
 * </p>
 */
public interface InputInterface extends
        ModulePropertyInterface {

    /**
     * <p>
     * Reads usecase collection from URL.
     * </p>
     * 
     * @param url
     *            URL where input is loaded from
     * @return Steps read from the input
     */
    public UseCaseCollection read(URL url) throws Exception;

    /**
     * <p>
     * Test if this input can read the data in specified
     * url.
     * </p>
     * 
     * @param url
     *            The url.
     * @return true If input can read the contents of the
     *         url.
     */
    public boolean canRead(URL url);

    /**
     * </p>
     * Returns inputs name as a String
     * </p>
     * 
     * @return name of this input
     */
    public String toString();

}
