/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.input;

/**
 * <p>
 * UseCase step class. Contains step's text and relation to
 * another usecase (sub-usecase)
 * </p>
 * 
 * @author vevijopi
 * 
 */
public class UseCaseStep {
    /**
     * Step description
     */
    private String step = new String();

    /**
     * Sub usecase for this step
     */
    private UseCase subUseCase = null;

    /**
     * Used to connect steps to sub-usecases. id of another
     * usecase (loaded from file). It is used to connect
     * these two together.
     */
    private String subUseCaseId = null;

    public UseCaseStep(String step, UseCase a) {
        this.step = step;
        subUseCase = a;
    }

    /**
     * Set sub usecase's id
     * 
     * @param id
     *            id of a subusecase for this step
     */
    public void setSubUseCaseId(String id) {
        subUseCaseId = id;
    }

    /**
     * Returns sub usecase's id
     * 
     * @return usecase id
     */
    public String getSubUseCaseId() {
        return subUseCaseId;
    }

    /**
     * Sets step's description
     * 
     * @param step
     *            description
     */
    public void setStep(String step) {
        this.step = step;
    }

    /**
     * Returns step's description
     * 
     * @return description
     */
    public String getStep() {
        return getStep(false);
    }

    /**
     * Returns step's description
     * 
     * @param showSubUsecaseName
     *            should the subusecase's name be shown
     *            aswell
     * @return description
     */
    public String getStep(boolean showSubUsecaseName) {
        if (!showSubUsecaseName || subUseCase == null) return step;
        return step + " (" + subUseCase.getName() + ")";
    }

    /**
     * returns sub usecase
     * 
     * @return sub usecase
     */
    public UseCase getSubUseCase() {
        return subUseCase;
    }

    /**
     * Sets sub usecase
     * 
     * @param usecase
     */
    public void setSubUseCase(UseCase usecase) {
        subUseCase = usecase;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#equals(java.lang.Object)
     */
    public boolean equals(Object o) {
        if (o instanceof UseCaseStep) {
            UseCaseStep other = (UseCaseStep) o;

            // Checking that wheither subusecases equals
            // could lead to infinite loops, so we don't
            // check them here
            return (this.getStep().equals(other.getStep()));
        }
        return false;
    }

    /**
     * returns this step as a string aswell as subusecase if
     * one exists
     */
    public String toString() {
        if (subUseCase == null) return step;
        return step + " -> " + subUseCase.toString();
    }

    public int hashCode() {
        if (step != null) return step.hashCode();

        return "".hashCode();
    }
}
