/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.model;

import java.util.Observer;

/**
 * <p>
 * Interface for analyze models.
 * </p>
 * 
 * <p>
 * Analyze model is class that represents the result of
 * UCOT-program. it is the internal representation of
 * analyzed use case.
 * </p>
 * 
 * <p>
 * Basically analyze model is builded from <i>entities</i>
 * that contains:
 * </p>
 * <ul>
 * <li>Methods</li>
 * <li>Attributes</li>
 * <li>Parents</li>
 * <li>Type</li>
 * </ul>
 * 
 * <p>
 * <b>Methods</b> are basically named relations that point
 * to some entity. Method can point back to its owner. There
 * can be only one method-relation that has same name and
 * point to same entity. It is also possibly that method
 * dont point to any entity. This just means that the method
 * exists, but it has no influence to other entity in the
 * analzyed model.
 * </p>
 * <p>
 * For example this interface has four methods. These can be
 * represented as method-relations:
 * </p>
 * <ol>
 * <li>
 * 
 * <pre>
 *  AnalyzeModel -- addObserver --&gt; Observer
 * </pre>
 * 
 * </li>
 * <li>
 * 
 * <pre>
 *  AnalyzeModel -- getEditor --&gt; ModelEditor
 * </pre>
 * 
 * </li>
 * <li>
 * 
 * <pre>
 *  AnalyzeModel -- readySignal --&gt;
 * </pre>
 * 
 * </li>
 * <li>
 * 
 * <pre>
 *  AnalyzeModel -- updationStartedSignla --&gt;
 * </pre>
 * 
 * </li>
 * </ol>
 * 
 * <p>
 * <b>Attributes</b> are relations between entities which
 * caries cardinal information. For example the
 * implementation of this class could have attribute that
 * has attribute-relation one-to-many to Observers.
 * </p>
 * <p>
 * <b>Parents</b> are the "superentities" of the entity.
 * These are same kind of consept like superclasses in java.
 * </p>
 * <p>
 * <b>Type</b> just a string that tells the type of the
 * entity.
 * </p>
 * 
 * @author pajumasu
 * 
 */
public interface AnalyzeModel {

    /**
     * <p>
     * Returns editor for this analyze model.
     * </p>
     * 
     * @return The ModelEditor that can be used to edit this
     *         model.
     */
    public ModelEditor getEditor();

    /**
     * <p>
     * Adds observer for this analyzemodel
     * </p>
     * 
     * @param observer
     *            The observer to be added.
     */
    public void addObserver(Observer observer);

}