/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.model;

/**
 * General exception used when attribute isn't found
 * 
 * @author tujupien
 * 
 */
public class NoSuchAttributeException extends
        AnalyzeModelException {

    private static final long serialVersionUID = 8915129262644339201L;

    /** The name of the entity. */
    String entityName;

    /** The name of the method */
    String attributeName;

    /**
     * <p>
     * Builds message for the error.
     * 
     * @param entityName
     *            The entity name used in the error.
     * @return The error message string.
     */
    private static String buildMessage(String entityName,
            String attributeName) {
        return "No such attribute '" + attributeName
                + "' in entity '" + entityName + "'.";
    }

    // TODO comment me
    private void setInternals(String entityName,
            String attributeName) {
        this.entityName = entityName;
        this.attributeName = attributeName;
    }

    // TODO comment me
    public NoSuchAttributeException(String entityName,
            String attributeName) {
        super(buildMessage(entityName, attributeName));
        setInternals(entityName, attributeName);
    }

    // TODO comment me
    public NoSuchAttributeException(String entityName,
            String attributeName, String message) {
        super(buildMessage(entityName, attributeName) + " "
                + message);
        setInternals(entityName, attributeName);
    }

    // TODO comment me
    public NoSuchAttributeException(String entityName,
            String attributeName, Throwable cause) {
        super(buildMessage(entityName, attributeName),
                cause);
        setInternals(entityName, attributeName);
    }

    // TODO comment me
    public NoSuchAttributeException(String entityName,
            String attributeName, String message,
            Throwable cause) {
        super(buildMessage(entityName, attributeName) + " "
                + message, cause);
        setInternals(entityName, attributeName);
    }

}
