/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.model;

/**
 * <p>
 * Error which is thrown when requested method is not found.
 * </p>
 * 
 * @author pajumasu
 * 
 */
public class NoSuchMethodException extends
        AnalyzeModelException {

    private static final long serialVersionUID = 733527374956747393L;

    /** The name of the entity. */
    String entityName;

    /** The name of the method */
    String methodName;

    /**
     * <p>
     * Builds message for the error.
     * 
     * @param entityName
     *            The entity name used in the error.
     * @return The error message string.
     */
    private static String buildMessage(String entityName,
            String methodName) {
        return "No such method '" + methodName
                + "' in entity '" + entityName + "'.";
    }

    // TODO comment me
    private void setInternals(String entityName,
            String methodName) {
        this.entityName = entityName;
        this.methodName = methodName;
    }

    // TODO comment me
    public NoSuchMethodException(String entityName,
            String methodName) {
        super(buildMessage(entityName, methodName));
        setInternals(entityName, methodName);
    }

    // TODO comment me
    public NoSuchMethodException(String entityName,
            String methodName, String message) {
        super(buildMessage(entityName, methodName) + " "
                + message);
        setInternals(entityName, methodName);
    }

    // TODO comment me
    public NoSuchMethodException(String entityName,
            String methodName, Throwable cause) {
        super(buildMessage(entityName, methodName), cause);
        setInternals(entityName, methodName);
    }

    // TODO comment me
    public NoSuchMethodException(String entityName,
            String methodName, String message,
            Throwable cause) {
        super(buildMessage(entityName, methodName) + " "
                + message, cause);
        setInternals(entityName, methodName);
    }

}
