/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.model.object;

import java.io.Serializable;
import java.util.HashSet;
import java.util.Iterator;
import java.util.Set;

/**
 * This class represents method of an entity.
 * 
 * @author pajumasu
 * 
 */
public class Method implements Serializable {
    public static final long serialVersionUID = 4346347435879039046L;

    /**
     * The name of the method.
     */
    private String name;

    /**
     * The list of entities that can be indluenced by this
     * method.
     */
    private Set<Entity> influenced = new HashSet<Entity>();

    /**
     * Creates new method called name. Methods name is
     * converted to lowercase.
     * 
     * @param name
     */
    public Method(String name) {
        setName(name);
    }

    /**
     * Sets the name of the method. Methods name is
     * converted to lowercase.
     * 
     * @param name
     */
    protected void setName(String name) {
        this.name = name.toLowerCase();
    }

    /**
     * Returns the set of entities that are influenced by
     * this method.
     * 
     * @return set of entities that are influenced by this
     *         method
     */
    public Set<Entity> getInfluenced() {

        // Remove entities that are marked deleted.
        for (Iterator<Entity> it = influenced.iterator(); it
                .hasNext();) {
            Entity entity = it.next();
            if (entity.deleted) it.remove();
        }

        Set<Entity> ret = new HashSet<Entity>();
        ret.addAll(influenced);
        // Return the set.
        return ret;
    }

    /**
     * Adds influence to this method.
     * 
     * @param entity
     */
    public void addInfluence(Entity entity) {
        influenced.add(entity);
    }

    /**
     * Removes influence from this method.
     * 
     * @param entity
     */
    public void removeInfluence(Entity entity) {
        influenced.remove(entity);
    }

    /**
     * Returns the name of the method.
     * 
     * @return name of the method
     */
    public String getName() {
        return name;
    }

}
