/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.model.object;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Observable;
import java.util.Set;

import ucot.model.AnalyzeModel;
import ucot.model.ModelEditor;
import ucot.utils.StringTools;

/**
 * Model that contains representation of the AnalyzeModel.
 * This implementation uses objects to contain the
 * information of the model.
 * 
 * @author pajumasu
 * 
 */
public class ObjectAnalyzeModel extends Observable
        implements AnalyzeModel, Serializable {
    public static final long serialVersionUID = 8923590437239046L;

    /**
     * The editor that edits this model
     */
    private ObjectAnalyzeModelEditor editor;

    /**
     * The entities that are containde by this model.
     */
    private Map<String, Entity> entities = new HashMap<String, Entity>();

    /**
     * Creates empty model.
     */
    public ObjectAnalyzeModel() {
        editor = new ObjectAnalyzeModelEditor(this);
    }

    /**
     * Returns entity.
     * 
     * @param name
     * @return entity
     */
    public Entity getEntity(String name) {
        return entities.get(StringTools.capitalize(name));
    }

    /**
     * Removes entity.
     * 
     * @param name
     *            The name of the entity.
     */
    public void removeEntity(String name) {
        Entity entity = entities.remove(name);
        if (null != entity) {
            // Mark entity deleted.
            entity.deleted = true;
        }

    }

    /**
     * Removes entity.
     * 
     * @param removeEntity
     *            The entity to be removoed
     */
    public void removeEntity(Entity removeEntity) {
        while (entities.values().remove(removeEntity)) {
            removeEntity.deleted = true;
        }

    }

    /**
     * Returns the names of the entities.
     * 
     * @return names of the entities
     */
    public Set<String> getEntityNames() {
        return entities.keySet();
    }

    /**
     * Adds an entity to the model.
     * 
     * @param entity
     */
    public void addEntity(Entity entity) {
        entity.deleted = false;
        Entity previous = entities.put(entity.getName(),
                entity);
        if (null != previous && !previous.equals(entity)) {
            previous.deleted = true;
        }
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.model.AnalyzeModel#clear()
     */
    public void clear() {
        entities.clear();

    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.model.AnalyzeModel#getEditor()
     */
    public ModelEditor getEditor() {
        return editor;
    }

    /*
     * Raises this metod to accessible from this package so
     * that model editor can use it too.
     * 
     * (non-Javadoc)
     * 
     * @see java.util.Observable#setChanged()
     */
    protected synchronized void setChanged() {
        super.setChanged();
    }

}
