/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.parser;

/**
 * <p>
 * Named link that points to some word. This class is used
 * to mark subjects and objects and other structural
 * information in sentence.
 * </p>
 * 
 * @see ucot.parser.Word
 * @see ucot.parser.Sentence
 */
public class Link {
    /**
     * The name of the link.
     * 
     * @see ParserInterface#SUBJECT
     * @see ParserInterface#OBJECT
     */
    private String name;

    /** The target word this class poitns to. */
    private Word to;

    /**
     * Returns the name of the link.
     * 
     * @return The name of the link.
     */
    public String getName() {
        return name;
    }

    /**
     * Sets the name of the link.
     * 
     * @param name
     */
    public void setName(String name) {
        this.name = name;
    }

    /**
     * Creates new named link that points to given word.
     * 
     * @param name
     *            The name of the link.
     * @param to
     *            The target word.
     */
    public Link(String name, Word to) {
        this.name = name;
        this.to = to;
    }

    /**
     * Returns the target of the link.
     * 
     * @return The target of the link.
     */
    public Word getTo() {
        return to;
    }

    /**
     * Sets the target of the link.
     * 
     * @param to
     *            The target for the link.
     */
    public void setTo(Word to) {
        this.to = to;
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.lang.Object#toString()
     */
    public String toString() {
        return getName() + " = " + to.getBasicForm();
    }

}
