/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.test;

import java.net.URL;

import junit.framework.Assert;
import junit.framework.TestCase;

import org.junit.Test;

import ucot.input.ProcessMLInputAdapter;
import ucot.input.SimpleInputAdapter;
import ucot.input.UseCaseCollection;

/**
 * This class implements test for the heuristics.
 * 
 * @author tujupien
 */
public class InputTest extends TestCase {

    final String testFileName = "Core-SimpleInputAdapter-UseCases-Test.txt";

    final String testProcMlFileName = "Core-ProcessMlInputAdapter-UseCases-Test.xml";

    /**
     * This method tests SimpleInputAdapter using badly
     * formed usecase file that contains three valid
     * usecases
     */
    @Test
    public void testSimpleInputAdapter() {
        System.out
                .println("TEST: Testing SimpleInputAdapter.");
        UseCaseCollection collection = null;
        URL file = null;
        SimpleInputAdapter input = new SimpleInputAdapter();

        try {
            file = new URL("file", "", -1, testFileName);
            // Test if we can read it
            if (!input.canRead(file)) {
                System.out.println("Can't read the file");
                Assert.fail();
                return;
            }
            // read it
            collection = input.read(file);
        } catch (Exception e) {
            e.printStackTrace();
            return;
        }

        // Only three usecase should be found, others aren't
        // valid
        // and one of them has a sub-usecase
        System.out.println(collection);
        Assert
                .assertEquals(3, collection
                        .getUseCaseCount());
    }

    /**
     * This method tests ProcessMlInputAdapter using badly
     * formed usecase file that still does contain a valid
     * usecase. If later on, dtd checking is added, this
     * test should be modified to fail if it is able to load
     * the usecase. Also add another proper usecase to test
     */
    @Test
    public void testProcessMlInputAdapter() {
        System.out
                .println("TEST: Testing SimpleInputAdapter.");
        UseCaseCollection collection = null;
        URL file = null;
        ProcessMLInputAdapter input = new ProcessMLInputAdapter();

        try {
            file = new URL("file", "", -1,
                    testProcMlFileName);
            if (!input.canRead(file)) {
                System.out.println("Can't read the file");
                Assert.fail();
                return;
            }

            collection = input.read(file);
        } catch (Exception e) {
            e.printStackTrace();
            return;
        }

        // Only three usecase should be found, others aren't
        // valid
        // and one of them has a sub-usecase
        System.out.println(collection);
        Assert
                .assertEquals(1, collection
                        .getUseCaseCount());
    }

}
