/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.ui.gui.dialog;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFrame;
import javax.swing.JPanel;
import javax.swing.JTextPane;

/**
 * About dialog for UCOT program. This dialog is inherited
 * from the Swing's JDialog class and can be constructed and
 * spawned to the screen with a static method:
 * showDialog(JFrame owner) This dialog is modal and will
 * halt all other execution until it's closed.
 * 
 * @author tujupien
 */
public class AboutDialog extends JDialog {

    private static final long serialVersionUID = -6739939273105582391L;

    protected static String DIALOG_HEADER = "About UCOT";

    protected static String TEXT = "UCOT is an excellent Use Case\n"
            + "to Object Model Technology!\n"
            + "\n"
            + "All your base are belong to us!";

    protected static String CLOSE_BUTTON_CAPTION = "Close";

    protected static String CLOSE_BUTTON_ACTION = "CLOSE";

    /**
     * Action listener for all buttons on this about dialog.
     */
    protected ActionListener buttonListener = new ActionListener() {
        /**
         * Action performed: User clicked the close button.
         */
        private void closeButtonClicked() {
            setVisible(false);
        }

        /**
         * This method handles all the button actions and
         * calls the correspondive methods to do their jobs.
         */
        public void actionPerformed(ActionEvent e) {
            if (CLOSE_BUTTON_ACTION.equals(e
                    .getActionCommand())) {
                closeButtonClicked();
            }
        }
    };

    /**
     * Constructor for about dialog. This constructor
     * initializes the whole dialog but does not set it
     * visible.
     * 
     * @param owner
     *            Owner of this about dialog.
     */
    public AboutDialog(JFrame owner) {
        super(owner, DIALOG_HEADER, true);
        this.setLayout(new BorderLayout());

        // Create panels for text and buttons.
        JPanel buttonPanel = new JPanel();
        JTextPane textPanel = new JTextPane();
        textPanel.setText(TEXT);
        textPanel.setBackground(this.getBackground());
        textPanel.setEditable(false);
        System.out.println(textPanel.getPreferredSize());
        System.out.println(textPanel.getText());
        this.getContentPane().add(buttonPanel,
                BorderLayout.SOUTH);
        this.getContentPane().add(textPanel,
                BorderLayout.NORTH);

        // Add close button to the dialog.
        JButton closeButton = new JButton(
                CLOSE_BUTTON_CAPTION);
        closeButton.addActionListener(buttonListener);
        closeButton.setActionCommand(CLOSE_BUTTON_ACTION);
        buttonPanel.add(closeButton);

        this.pack();
        this.setResizable(false);
    }

    /**
     * Static method for initializing an about dialog and
     * spawning it to the screen.
     * 
     * @param owner
     *            Owner of this about dialog.
     */
    public static void showDialog(JFrame owner) {
        AboutDialog dialog = new AboutDialog(owner);
        dialog.setVisible(true);
    }
}
