/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.ui.gui.dialog;

import java.awt.BorderLayout;
import java.awt.FlowLayout;

import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JProgressBar;

import ucot.ui.ProgressBarInterface;
import ucot.ui.gui.GUIUtils;
import ucot.ui.gui.GraphicalUI;

/**
 * <p>
 * Progressbar dialog class.
 * </p>
 * 
 * @author tujupien
 * 
 */
public class ProgressBarDialog extends JDialog implements
        ProgressBarInterface {

    private static final long serialVersionUID = -339409755317502298L;

    private JProgressBar progressBar = new JProgressBar();

    private JLabel description = new JLabel("");

    private GraphicalUI owner;

    /**
     * Default constructor for ProgressBarDialog.
     * 
     * @param owner
     *            Owner of this dialog.
     * @param title
     *            Title of this this dialog.
     */
    public ProgressBarDialog(GraphicalUI owner, String title) {
        super(owner, title);
        this.owner = owner;
        setLayout(new BorderLayout());

        JPanel progressBarPanel = new JPanel();
        progressBarPanel.setLayout(new FlowLayout(
                FlowLayout.CENTER, 10, 10));
        progressBarPanel.add(progressBar);
        JPanel descriptionPanel = new JPanel();
        descriptionPanel.setLayout(new FlowLayout(
                FlowLayout.CENTER, 10, 10));
        descriptionPanel.add(description);

        getContentPane().add(progressBarPanel,
                BorderLayout.NORTH);
        getContentPane().add(descriptionPanel,
                BorderLayout.SOUTH);

        progressBar.setStringPainted(true);
        setMinimum(0);
        setMaximum(100);
        setValue(0);
        setString("");

        this.pack();
        GUIUtils.centerDialog(this);
        this
                .setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
        this.setVisible(false);
        this.setResizable(false);
        this.setAlwaysOnTop(true);
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#getMaximum()
     */
    public int getMaximum() {
        return progressBar.getMaximum();
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#getMinimum()
     */
    public int getMinimum() {
        return progressBar.getMinimum();
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#getPercentageComplete()
     */
    public double getPercentageComplete() {
        return progressBar.getPercentComplete();
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#getString()
     */
    public String getString() {
        return progressBar.getString();
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#getValue()
     */
    public int getValue() {
        return progressBar.getValue();
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#setMaximum(int)
     */
    public void setMaximum(int maximum) {
        progressBar.setMaximum(maximum);
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#setMinimum(int)
     */
    public void setMinimum(int minimum) {
        progressBar.setMaximum(minimum);
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#setString(java.lang.String)
     */
    public void setString(String string) {
        description.setText(string);
        pack();
        // GUIUtils.centerDialog(this);
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.core.ProgressBar#setValue(int)
     */
    public void setValue(int value) {
        progressBar.setValue(value);
        progressBar.setString(Integer
                .toString((int) Math.floor(progressBar
                        .getPercentComplete() * 100))
                + " %");
    }

    /*
     * (non-Javadoc)
     * 
     * @see java.awt.Component#setVisible(boolean)
     */
    public void setVisible(boolean visible) {
        super.setVisible(visible);
        this.owner.setDisabled(visible);
    }
}
