/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.ui.gui.dialog.entitytab;

import java.awt.BorderLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.HashMap;
import java.util.Map;

import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTable;
import javax.swing.table.DefaultTableModel;

/**
 * <p>
 * This is basic panel that contains table and panel for
 * buttons. It is generalized interface for making basic
 * modifications in some data. This should be extended for
 * specialized purposes, but it is not nessesary.
 * </p>
 * <p>
 * To use this class by extending it only action method
 * should be overrided. It can be used to react the user
 * interaction with buttons.
 * </p>
 * 
 * <pre><code>
 * class SomeExtenderClass extends JTableAndButtonsPanel {
 *     public void action(String cmd) {
 *         if (BUTTON_1_ACTIONequals(cmd)) {
 *             doAction1();
 *             return;
 *         }
 * 
 *         if (BUTTON_2_ACTION.equals(cmd)) {
 *             doAction2();
 *             return;
 *         }
 *     }
 * 
 *     public SomeExtenderClass() {
 *         super(&quot;Header&quot;,
 *                 new String[] { &quot;Column1&quot;, &quot;Columnt&quot; });
 *         // Create some buttons
 *         addButton(BUTTON_1_NAME, BUTTON_1_ACTION);
 *         addButton(BUTTON_2_NAME, BUTTON_2_ACTION);
 *     }
 * }
 * </code></pre>
 * 
 * <p>
 * If this is used as direct component added buttons should
 * contain proper <code>ActionListener</code> the code to
 * react their events.
 * </p>
 * 
 * <pre><code>
 *   class SomeClass{
 *    public MethodsPanel(){
 *        JTableAndButtonsPanel panel = 
 *  			new JTableAndButtonsPanel(&quot;Header&quot;,new String[]{&quot;Column1&quot;,&quot;Columnt&quot;});
 *   		// Create some buttons
 *  		panel.addButton(BUTTON_1_NAME,BUTTON_1_ACTION).addActionListener(
 *  					new ActionListener(){
 *  						public void actionPerformed(ActionEvent e) {
 *  							doAction1;		
 *  		                }
 *  					});
 *  		panel.addButton(BUTTON_1_NAME,BUTTON_1_ACTION).addActionListener(
 *  					new ActionListener(){
 *  						public void actionPerformed(ActionEvent e) {
 *  							doAction2;		
 *  		                }
 *  					});	
 *  	}
 * </code></pre>
 * 
 */
public class JTableAndButtonsPanel extends JPanel {
    Map<String, JButton> buttons = new HashMap<String, JButton>();

    private static final long serialVersionUID = -3785955762470238856L;

    private JPanel buttonsPanel;

    private JTable table;

    private JPanel containerPanel;

    private JScrollPane scrollPane;

    private ActionListener actionListener = new ActionListener() {

        public void actionPerformed(ActionEvent e) {
            action(e.getActionCommand());
        }

    };

    /**
     * <p>
     * Creates the panel with empty table and no buttons.
     * </p>
     */
    public JTableAndButtonsPanel() {
        DefaultTableModel tableModel = new DefaultTableModel();

        containerPanel = new JPanel();
        buttonsPanel = new JPanel();
        containerPanel.setLayout(new BorderLayout());
        table = new JTable(tableModel);
        table.setRowSelectionAllowed(false);

        scrollPane = new JScrollPane();
        scrollPane.setAutoscrolls(true);

        setTable(table);

        containerPanel.add(scrollPane, BorderLayout.CENTER);
        this.setLayout(new BorderLayout());
        this.add(containerPanel, BorderLayout.CENTER);
        this.add(buttonsPanel, BorderLayout.SOUTH);

    }

    // TODO comment me
    public void setTable(JTable newTable) {
        scrollPane.remove(table);
        scrollPane.setViewportView(newTable);
        table = newTable;
    }

    // TODO comment me
    public JTable getTable() {
        return table;
    }

    // TODO comment me
    public JButton addButton(String label,
            String actionCommand) {
        JButton button = new JButton(label);
        button.setActionCommand(actionCommand);
        buttonsPanel.add(button);
        button.addActionListener(actionListener);
        return button;
    }

    protected void action(String actionCmd) {
    }
}
