/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.ui.gui.dialog.entitytab;

import java.util.Set;

import javax.swing.JComponent;
import javax.swing.table.DefaultTableModel;
import javax.swing.table.TableColumn;

import ucot.model.AnalyzeModel;
import ucot.ui.gui.GUIUtils;

// TODO comment me
public abstract class JTableEntityPropertiesTab extends
        JTableAndButtonsPanel implements
        EntityPropertiesEditor {

    DefaultTableModel tableModel = new DefaultTableModel();

    String[] columnNames;

    String tabName;

    public JTableEntityPropertiesTab(String name,
            String[] columnNames) {
        tabName = name;
        this.columnNames = columnNames;
        getTable().setModel(tableModel);
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.dialog.entitytab.EntityPropertiesEditor#getTabName()
     */
    public String getTabName() {
        return tabName;
    }

    // TODO comment me
    /**
     * @return model
     */
    public DefaultTableModel getModel() {
        return tableModel;
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.dialog.entitytab.EntityPropertiesEditor#clear()
     */
    public void clear() {
        // Erase all data from old table models.
        for (int i = tableModel.getRowCount() - 1; i >= 0; i--)
            tableModel.removeRow(i);
    };

    // TODO comment me
    /**
     * 
     * @param analyzeModel
     *            analyze model to use
     * @param entityName
     *            entity to
     * @param column_index
     * @param allowSelf
     */
    public void updateCellEditor(AnalyzeModel analyzeModel,
            String entityName, int column_index,
            boolean allowSelf) {
        Set<String> entities = analyzeModel.getEditor()
                .getEntityNames();
        String[] entitiesArray = new String[entities.size()];
        entitiesArray = entities.toArray(entitiesArray);
        TableColumn column = getTable().getColumnModel()
                .getColumn(column_index);
        column.setCellEditor(GUIUtils
                .createComboBoxCellEditor(entitiesArray,
                        entityName, SELF_POINTER_NAME,
                        allowSelf, true));
    }

    /**
     * Sets the column names
     * 
     * @param columnNames
     *            array of column names to set
     */
    public void setColumns(String[] columnNames) {
        this.columnNames = columnNames;
        getModel().setColumnCount(columnNames.length);
        getModel().setColumnIdentifiers(columnNames);
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.dialog.entitytab.EntityPropertiesEditor#load(ucot.model.AnalyzeModel,
     *      java.lang.String)
     */
    public void load(AnalyzeModel analyzeModel,
            String entityName) {
        setColumns(columnNames);
    };

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.dialog.entitytab.EntityPropertiesEditor#save(ucot.model.AnalyzeModel,
     *      java.lang.String)
     */
    public void save(AnalyzeModel model, String entityName) {
        if (getTable().isEditing()) getTable()
                .getCellEditor().stopCellEditing();
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.dialog.entitytab.EntityPropertiesEditor#getComponent()
     */
    public JComponent getComponent() {
        return this;
    };

}
