/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.ui.gui.tree.analyzemodeltree;

import java.util.List;
import java.util.Set;
import java.util.Vector;

import javax.swing.Icon;

/**
 * <p>
 * This class represents method <code>TreeItem</code>.
 * </p>
 */
public class MethodTreeItem extends TreeItem {

    /** The name of the entity that this method belongs to. */
    String entity;

    /**
     * <p>
     * Costructs the object.
     * </p>
     * 
     * @param entity
     *            The name of the entity that the method
     *            belongs to.
     * @param method
     *            The name of the menthod.
     * @param model
     *            The <code>TreeModel</code> this item
     *            belongs to.
     * @param parent
     *            The parent node.
     */
    public MethodTreeItem(String entity, String method,
            AnalyzeTreeModel model, TreeItem parent) {
        super(method, model, parent);
        this.entity = entity;
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.tree.analyzemodeltree.TreeItem#getChildren()
     */
    @SuppressWarnings(value = { "unchecked" } // Suppreess
                                                // type
                                                // safty
    // checking.
    )
    @Override
    public List getChildren() {
        List<TreeItem> items = new Vector<TreeItem>();
        Set<String> relatedEntities = getAnalyzeModel()
                .getEditor().getEntitiesInfluencedByMethod(
                        entity, getName());
        for (String entity : relatedEntities) {
            TreeItem item = new EntityTreeItem(entity,
                    getTreeModel(), this, true);
            items.add(item);
        }
        return items;
    }

    @Override
    public Icon getIcon() {
        return AnalyzeModelTree.methodIcon;
    }
}
