/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.ui.gui.tree.usecasetree;

import java.io.File;
import java.net.URL;
import java.util.List;
import java.util.Vector;

import javax.swing.Icon;
import javax.swing.filechooser.FileSystemView;

/**
 * <p>
 * Root node for <code>UseCaseTree</code>.
 * </p>
 * 
 * 
 * 
 * @author ilanliuk
 * 
 */
public class FilesTreeItem extends TreeItem {

    private static Icon directoryIcon = getDirectoryIcon();

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.tree.usecasetree.TreeItem#getIcon()
     */
    @SuppressWarnings(value = { "static-access" } // Suppreess
                                                    // static
                                                    // access
    // warning.
    )
    @Override
    public Icon getIcon() {
        return this.directoryIcon;
    }

    /**
     * <p>
     * Default constructor for FilesTreeItem.
     * </p>
     * 
     * @param treemodel
     *            <code>UseCaseTreeModel</code> that uses
     *            this <code>FilesTreeItem</code>.
     * @param parent
     *            parent node of this node.
     */
    public FilesTreeItem(UseCaseTreeModel treemodel,
            TreeItem parent) {
        super(treemodel, parent);
    }

    @Override
    public String getName() {
        return "Files";
    }

    /*
     * (non-Javadoc)
     * 
     * @see ucot.ui.gui.tree.usecasetree.TreeItem#getChildren()
     */
    @SuppressWarnings(value = { "unchecked" } // Suprreess
                                                // type
                                                // safty
    // warnings.
    )
    @Override
    public List getChildren() {
        List<FileTreeItem> children = new Vector<FileTreeItem>();
        List<URL> urls = treemodel.getUseCaseCollection()
                .getURLs();
        for (URL url : urls) {
            children.add(new FileTreeItem(this.treemodel,
                    this, url));
        }
        return children;
    }

    /**
     * <p>
     * Returns file systems default directory icon.
     * </p>
     * 
     * <p>
     * Ask file systems default directory <code>Icon</code>
     * from <code>FileSystemView</code>.
     * </p>
     * 
     * @return File systems <code>Icon</code> for
     *         directory.
     * 
     * @see FileSystemView
     */
    private static Icon getDirectoryIcon() {
        File directory = new File(".");
        FileSystemView filesystemview = FileSystemView
                .getFileSystemView();
        return filesystemview.getSystemIcon(directory);
    }
}
