/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.utils;

import java.util.HashSet;
import java.util.Set;

/**
 * Operations to use sets.
 * 
 * @author pajumasu
 * 
 */
public class Sets {
    /**
     * Item must be in both sets to be in the resulting set.
     * 
     * @param <T>
     *            The type of the items.
     * @param set1
     *            The first set.
     * @param set2
     *            The second set.
     * @return The intersection of both sets.
     */
    public static <T> Set<T> intersection(Set<T> set1,
            Set<T> set2) {
        Set<T> result = new HashSet<T>();
        result.addAll(set1);
        result.retainAll(set2);
        return result;
    }

    /**
     * Returns set items that are missing in second set.
     * 
     * @param <T>
     * @param set1
     * @param set2
     * @return The set of items that ar in set2 but not in
     *         set1.
     */
    public static <T> Set<T> missing(Set<T> set1,
            Set<T> set2) {
        Set<T> result = new HashSet<T>();
        result.addAll(set2);
        result.removeAll(set1);
        return result;
    }

}
