/*
 *  Copyright (C) 2006  UCOT
 *
 *  Distributed under the terms of the MIT License.
 *  See "LICENCE" or http://www.opensource.org/licenses/mit-license.php for details.
 */
package ucot.utils;

import java.io.PrintWriter;
import java.io.StringWriter;
import java.util.StringTokenizer;

/**
 * This class contians tools for string handling.
 */
public class StringTools {

    /**
     * Returns string which starts with uppercase letter.
     * 
     * @param str
     *            The string to be capitalized.
     * @return The capitalized string.
     */
    public static String capitalize(String str) {
        if (str == null) return null;
        if (str.length() == 0) return str;
        return Character.toUpperCase(str.charAt(0))
                + str.substring(1);
    }

    /**
     * Returns string which starts with lowercase letter.
     * 
     * @param str
     *            The string to be decapitalized.
     * @return
     * @return The decapitalized string.
     */
    public static String decapitalize(String str) {
        if (str == null) return null;
        if (str.length() == 0) return str;
        return Character.toLowerCase(str.charAt(0))
                + str.substring(1);
    }

    /**
     * Returns stack trace of throwable object as a string.
     * 
     * @param t
     *            The throwable object.
     * @return String representation of the stack trace.
     */
    public static String exceptionStackTrace(Throwable t) {
        StringWriter writer = new StringWriter();
        t.printStackTrace(new PrintWriter(writer));
        return writer.toString();
    }

    /**
     * Removes all white space characters (spaces, tabs and
     * line breaks).
     * 
     * @param str
     *            The string to be shortened.
     * @return string with the whitespaces removed
     */
    public static String removeWhitespaces(String str) {
        String tmp = str;

        // Replace every whitspace with simple space.
        tmp = tmp.replace("\r", " ");
        tmp = tmp.replace("\n", " ");
        tmp = tmp.replace("\t", " ");

        // Leave only one space between the words.
        StringTokenizer st = new StringTokenizer(tmp, " ",
                false);
        StringBuffer sb = new StringBuffer();
        while (st.hasMoreTokens()) {
            String token = st.nextToken();
            if (!token.equals(" ")) {
                sb.append(token);
                sb.append(" ");
            }
        }

        return sb.toString().trim();
    }
}
